@@ -3,6 +3,11 @@ from .._impl import (
     authentication_api_AppearanceSetting as AppearanceSetting,
     authentication_api_AuthenticationServiceV2 as AuthenticationServiceV2,
     authentication_api_DefaultTimeRangeTypeSetting as DefaultTimeRangeTypeSetting,
+    authentication_api_GenerateMediaMtxTokenRequest as GenerateMediaMtxTokenRequest,
+    authentication_api_GenerateMediaMtxTokenResponse as GenerateMediaMtxTokenResponse,
+    authentication_api_Jwk as Jwk,
+    authentication_api_Jwks as Jwks,
+    authentication_api_MediaMtxPermission as MediaMtxPermission,
     authentication_api_OrgRid as OrgRid,
     authentication_api_OrgSettings as OrgSettings,
     authentication_api_SearchUsersQuery as SearchUsersQuery,
@@ -21,6 +26,11 @@ from .._impl import (
 __all__ = [
     'AppearanceSetting',
     'DefaultTimeRangeTypeSetting',
+    'GenerateMediaMtxTokenRequest',
+    'GenerateMediaMtxTokenResponse',
+    'Jwk',
+    'Jwks',
+    'MediaMtxPermission',
     'OrgRid',
     'OrgSettings',
     'SearchUsersQuery',
