@@ -17,6 +17,7 @@ from .._impl import (
     scout_compute_api_ArrowBucketedEnumPlot as ArrowBucketedEnumPlot,
     scout_compute_api_ArrowBucketedNumericPlot as ArrowBucketedNumericPlot,
     scout_compute_api_ArrowEnumPlot as ArrowEnumPlot,
+    scout_compute_api_ArrowFullResolutionPlot as ArrowFullResolutionPlot,
     scout_compute_api_ArrowNumericPlot as ArrowNumericPlot,
     scout_compute_api_AssetChannel as AssetChannel,
     scout_compute_api_Average as Average,
@@ -254,9 +255,7 @@ from .._impl import (
     scout_compute_api_PageStrategyVisitor as PageStrategyVisitor,
     scout_compute_api_PageToken as PageToken,
     scout_compute_api_PageTokenVisitor as PageTokenVisitor,
-    scout_compute_api_PagedEnumArrayPlot as PagedEnumArrayPlot,
     scout_compute_api_PagedLogPlot as PagedLogPlot,
-    scout_compute_api_PagedNumericArrayPlot as PagedNumericArrayPlot,
     scout_compute_api_ParameterInput as ParameterInput,
     scout_compute_api_ParameterizedComputeNodeRequest as ParameterizedComputeNodeRequest,
     scout_compute_api_ParameterizedComputeNodeResponse as ParameterizedComputeNodeResponse,
@@ -354,6 +353,8 @@ from .._impl import (
     scout_compute_api_TimestampAndId as TimestampAndId,
     scout_compute_api_TimestampConstant as TimestampConstant,
     scout_compute_api_TimestampConstantVisitor as TimestampConstantVisitor,
+    scout_compute_api_TruncateStrategy as TruncateStrategy,
+    scout_compute_api_TruncateStrategyVisitor as TruncateStrategyVisitor,
     scout_compute_api_UnaryArithmeticOperation as UnaryArithmeticOperation,
     scout_compute_api_UnaryArithmeticSeries as UnaryArithmeticSeries,
     scout_compute_api_UnboundedBehavior as UnboundedBehavior,
@@ -395,6 +396,7 @@ __all__ = [
     'ArrowBucketedEnumPlot',
     'ArrowBucketedNumericPlot',
     'ArrowEnumPlot',
+    'ArrowFullResolutionPlot',
     'ArrowNumericPlot',
     'AssetChannel',
     'Average',
@@ -631,9 +633,7 @@ __all__ = [
     'PageStrategyVisitor',
     'PageToken',
     'PageTokenVisitor',
-    'PagedEnumArrayPlot',
     'PagedLogPlot',
-    'PagedNumericArrayPlot',
     'ParameterInput',
     'ParameterizedComputeNodeRequest',
     'ParameterizedComputeNodeResponse',
@@ -731,6 +731,8 @@ __all__ = [
     'TimestampAndId',
     'TimestampConstant',
     'TimestampConstantVisitor',
+    'TruncateStrategy',
+    'TruncateStrategyVisitor',
     'UnaryArithmeticOperation',
     'UnaryArithmeticSeries',
     'UnboundedBehavior',
